nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Dmac1OtrigSel

Struct Dmac1OtrigSel 

#[repr(transparent)]
pub struct Dmac1OtrigSel(pub u32);
DMAC1 Output Trigger Multiplexers N

Tuple Fields

0: u32

Implementations

Source

impl Dmac1OtrigSel

pub const fn dmac1_otrig_sel(&self) -> Dmac1OtrigSel

DMA1 Output Triggers Select for A, B, C, D IE., DMA1_OTRIG_A, DMA1_OTRIG_B, DM1_OTRIG_C, DMA1_OTRIG_D DMA0 Output Triggers(n) Selection. 32:1 Selection for each. . .

pub const fn set_dmac1_otrig_sel(&mut self, val: Dmac1OtrigSel)

DMA1 Output Triggers Select for A, B, C, D IE., DMA1_OTRIG_A, DMA1_OTRIG_B, DM1_OTRIG_C, DMA1_OTRIG_D DMA0 Output Triggers(n) Selection. 32:1 Selection for each. . .