#[repr(transparent)]pub struct PintSel(pub u32);Expand description
GPIO Pin Input Multiplexer N
Tuple Fields
0: u32Implementations
Sourceimpl PintSel
impl PintSel
Sourcepub const fn pint_sel(&self) -> u8
pub const fn pint_sel(&self) -> u8
Port Input (PIOx.y) 64 to 8 Mux Select. . . Pin number select for pin interrupt or pattern match engine input. (For PIOx_y: INTPIN = (x * 32) + y. PIO0_0 to PIO1_31 correspond to numbers 0 to 63.
Sourcepub const fn set_pint_sel(&mut self, val: u8)
pub const fn set_pint_sel(&mut self, val: u8)
Port Input (PIOx.y) 64 to 8 Mux Select. . . Pin number select for pin interrupt or pattern match engine input. (For PIOx_y: INTPIN = (x * 32) + y. PIO0_0 to PIO1_31 correspond to numbers 0 to 63.