#[repr(transparent)]pub struct Dmac0OtrigSel(pub u32);Expand description
DMAC0 Output Trigger Multiplexers N
Tuple Fields
0: u32Implementations
Sourceimpl Dmac0OtrigSel
impl Dmac0OtrigSel
Sourcepub const fn dmac0_otrig_sel(&self) -> Dmac0OtrigSel
pub const fn dmac0_otrig_sel(&self) -> Dmac0OtrigSel
DMAC0 Output Triggers Select for A, B, C, D IE.,DMAC0_OTRIG_A, DMAC0_OTRIG_B, DMAC0_OTRIG_C, DMAC0_OTRIG_D DMA0 Output Triggers(n) Selection. 32:1 Selection for each. . .
Sourcepub const fn set_dmac0_otrig_sel(&mut self, val: Dmac0OtrigSel)
pub const fn set_dmac0_otrig_sel(&mut self, val: Dmac0OtrigSel)
DMAC0 Output Triggers Select for A, B, C, D IE.,DMAC0_OTRIG_A, DMAC0_OTRIG_B, DMAC0_OTRIG_C, DMAC0_OTRIG_D DMA0 Output Triggers(n) Selection. 32:1 Selection for each. . .