#[repr(transparent)]pub struct Dmac1OtrigSel(pub u32);Expand description
DMAC1 Output Trigger Multiplexers N
Tuple Fields
0: u32Implementations
Sourceimpl Dmac1OtrigSel
impl Dmac1OtrigSel
Sourcepub const fn dmac1_otrig_sel(&self) -> Dmac1OtrigSel
pub const fn dmac1_otrig_sel(&self) -> Dmac1OtrigSel
DMA1 Output Triggers Select for A, B, C, D IE., DMA1_OTRIG_A, DMA1_OTRIG_B, DM1_OTRIG_C, DMA1_OTRIG_D DMA0 Output Triggers(n) Selection. 32:1 Selection for each. . .
Sourcepub const fn set_dmac1_otrig_sel(&mut self, val: Dmac1OtrigSel)
pub const fn set_dmac1_otrig_sel(&mut self, val: Dmac1OtrigSel)
DMA1 Output Triggers Select for A, B, C, D IE., DMA1_OTRIG_A, DMA1_OTRIG_B, DM1_OTRIG_C, DMA1_OTRIG_D DMA0 Output Triggers(n) Selection. 32:1 Selection for each. . .